==> alfresco-repository-23.6.0.31-sources.jar: org/alfresco/service/cmr/invitation/NominatedInvitation.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.invitation;

import java.util.Date;


/**
 * The nominated invitation is a model object for who, needs to be added or removed 
 * from which resource with which attributes.
 * 
 * Invitations are processed by the InvitationService
 * 
 * @see org.alfresco.service.cmr.invitation.InvitationService
 *
 * @author mrogers
 */
public interface NominatedInvitation extends Invitation
{
	public String getInviterUserName();

	public String getInviteeFirstName();

	public String getInviteeLastName();

	public String getInviteeEmail();

	public String getResourceName();

    public String getResourceTitle();

    public String getResourceDescription();

	public String getServerPath();

	public String getAcceptUrl();

	public String getRejectUrl();

	public Date getSentInviteDate();
	
	public String getTicket();
}

==> alfresco-repository-25.2.1.2-sources.jar: org/alfresco/service/cmr/invitation/NominatedInvitation.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.invitation;

import java.util.Date;

/**
 * The nominated invitation is a model object for who, needs to be added or removed from which resource with which attributes.
 * 
 * Invitations are processed by the InvitationService
 * 
 * @see org.alfresco.service.cmr.invitation.InvitationService
 *
 * @author mrogers
 */
public interface NominatedInvitation extends Invitation
{
    public String getInviterUserName();

    public String getInviteeFirstName();

    public String getInviteeLastName();

    public String getInviteeEmail();

    public String getResourceName();

    public String getResourceTitle();

    public String getResourceDescription();

    public String getServerPath();

    public String getAcceptUrl();

    public String getRejectUrl();

    public Date getSentInviteDate();

    public String getTicket();
}
